View Javadoc

1   /**
2    * Licensed to jclouds, Inc. (jclouds) under one or more
3    * contributor license agreements.  See the NOTICE file
4    * distributed with this work for additional information
5    * regarding copyright ownership.  jclouds licenses this file
6    * to you under the Apache License, Version 2.0 (the
7    * "License"); you may not use this file except in compliance
8    * with the License.  You may obtain a copy of the License at
9    *
10   *   http://www.apache.org/licenses/LICENSE-2.0
11   *
12   * Unless required by applicable law or agreed to in writing,
13   * software distributed under the License is distributed on an
14   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
15   * KIND, either express or implied.  See the License for the
16   * specific language governing permissions and limitations
17   * under the License.
18   */
19  package org.jclouds.aws.ec2.reference;
20  
21  import org.jclouds.ec2.domain.InstanceType;
22  import org.jclouds.ec2.reference.EC2Constants;
23  
24  /**
25   * Configuration properties and constants used in EC2 connections.
26   * 
27   * @author Adrian Cole
28   */
29  public interface AWSEC2Constants extends EC2Constants {
30  
31     /**
32      * amis that work on the cluster instance type
33      * 
34      * @see InstanceType.CC1_4XLARGE
35      */
36     @Deprecated
37     public static final String PROPERTY_EC2_CC_AMIs = "jclouds.ec2.cc-amis";
38     /**
39      * expression to find amis that work on the cluster instance type <br/>
40      * ex. {@code
41      * virtualization-type=hvm;architecture=x86_64;owner-id=137112412989,099720109477;hypervisor=xen;
42      * state=available;image-type=machine;root-device-type=ebs}
43      * 
44      * @see InstanceType.CC1_4XLARGE
45      */
46     public static final String PROPERTY_EC2_CC_AMI_QUERY = "jclouds.ec2.cc-ami-query";
47     public static final String PROPERTY_EC2_CC_REGIONS = "jclouds.ec2.cc-regions";
48     public static final String PROPERTY_EC2_AMI_QUERY = "jclouds.ec2.ami-query";
49     /**
50      * If this property is set to true(default), jclouds generate a name for each instance based on
51      * the group. ex. i-ef34ae2 becomes hadoop-ef34ae2.
52      */
53     public static final String PROPERTY_EC2_GENERATE_INSTANCE_NAMES = "jclouds.ec2.generate-instance-names";
54  
55  }