1 /**
2 *
3 * Copyright (C) 2011 Cloud Conscious, LLC. <info@cloudconscious.com>
4 *
5 * ====================================================================
6 * Licensed under the Apache License, Version 2.0 (the "License");
7 * you may not use this file except in compliance with the License.
8 * You may obtain a copy of the License at
9 *
10 * http://www.apache.org/licenses/LICENSE-2.0
11 *
12 * Unless required by applicable law or agreed to in writing, software
13 * distributed under the License is distributed on an "AS IS" BASIS,
14 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
15 * See the License for the specific language governing permissions and
16 * limitations under the License.
17 * ====================================================================
18 */
19 package org.jclouds.aws.ec2.reference;
20
21 /**
22 *
23 * Copyright (C) 2010 Cloud Conscious, LLC. <info@cloudconscious.com>
24 *
25 * ====================================================================
26 * Licensed under the Apache License, Version 2.0 (the "License");
27 * you may not use this file except in compliance with the License.
28 * You may obtain a copy of the License at
29 *
30 * http://www.apache.org/licenses/LICENSE-2.0
31 *
32 * Unless required by applicable law or agreed to in writing, software
33 * distributed under the License is distributed on an "AS IS" BASIS,
34 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
35 * See the License for the specific language governing permissions and
36 * limitations under the License.
37 * ====================================================================
38 */
39
40 import org.jclouds.ec2.domain.InstanceType;
41 import org.jclouds.ec2.reference.EC2Constants;
42
43 /**
44 * Configuration properties and constants used in EC2 connections.
45 *
46 * @author Adrian Cole
47 */
48 public interface AWSEC2Constants extends EC2Constants {
49
50 /**
51 * amis that work on the cluster instance type
52 *
53 * @see InstanceType.CC1_4XLARGE
54 */
55 @Deprecated
56 public static final String PROPERTY_EC2_CC_AMIs = "jclouds.ec2.cc-amis";
57 /**
58 * expression to find amis that work on the cluster instance type <br/>
59 * ex. {@code
60 * virtualization-type=hvm;architecture=x86_64;owner-id=137112412989,099720109477;hypervisor=xen;
61 * state=available;image-type=machine;root-device-type=ebs}
62 *
63 * @see InstanceType.CC1_4XLARGE
64 */
65 public static final String PROPERTY_EC2_CC_AMI_QUERY = "jclouds.ec2.cc-ami-query";
66 public static final String PROPERTY_EC2_CC_REGIONS = "jclouds.ec2.cc-regions";
67 public static final String PROPERTY_EC2_AMI_QUERY = "jclouds.ec2.ami-query";
68
69 }